Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(162)

Unified Diff: src/doc/SkDocument.cpp

Issue 1316233002: Style Change: NULL->nullptr (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: 2015-08-27 (Thursday) 10:25:06 EDT Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/device/xps/SkXPSDevice.cpp ('k') | src/doc/SkDocument_PDF.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/doc/SkDocument.cpp
diff --git a/src/doc/SkDocument.cpp b/src/doc/SkDocument.cpp
index 5b2237d18a661312ba2d620e835bae26ed7fc3e6..fa25e44f8645bb0c99d89015691bd42ce993d0f1 100644
--- a/src/doc/SkDocument.cpp
+++ b/src/doc/SkDocument.cpp
@@ -21,7 +21,7 @@ SkDocument::~SkDocument() {
SkCanvas* SkDocument::beginPage(SkScalar width, SkScalar height,
const SkRect* content) {
if (width <= 0 || height <= 0) {
- return NULL;
+ return nullptr;
}
SkRect outer = SkRect::MakeWH(width, height);
@@ -29,7 +29,7 @@ SkCanvas* SkDocument::beginPage(SkScalar width, SkScalar height,
if (content) {
inner = *content;
if (!inner.intersect(outer)) {
- return NULL;
+ return nullptr;
}
} else {
inner = outer;
@@ -44,11 +44,11 @@ SkCanvas* SkDocument::beginPage(SkScalar width, SkScalar height,
this->endPage();
break;
case kClosed_State:
- return NULL;
+ return nullptr;
}
}
SkDEBUGFAIL("never get here");
- return NULL;
+ return nullptr;
}
void SkDocument::endPage() {
@@ -68,9 +68,9 @@ bool SkDocument::close() {
if (fDoneProc) {
fDoneProc(fStream, false);
}
// we don't own the stream, but we mark it NULL since we can
// no longer write to it.
- fStream = NULL;
+ fStream = nullptr;
return success;
}
case kInPage_State:
@@ -89,7 +89,7 @@ void SkDocument::abort() {
if (fDoneProc) {
fDoneProc(fStream, true);
}
// we don't own the stream, but we mark it NULL since we can
// no longer write to it.
- fStream = NULL;
+ fStream = nullptr;
}
« no previous file with comments | « src/device/xps/SkXPSDevice.cpp ('k') | src/doc/SkDocument_PDF.cpp » ('j') | no next file with comments »
@@ -68,9 +68,9 @@ bool SkDocument::close() {
fDoneProc(fStream, false);
}
- // we don't own the stream, but we mark it NULL since we can
+ // we don't own the stream, but we mark it nullptr since we can
// no longer write to it.
@@ -89,7 +89,7 @@ void SkDocument::abort() {
fDoneProc(fStream, true);
}
- // we don't own the stream, but we mark it NULL since we can
+ // we don't own the stream, but we mark it nullptr since we can
// no longer write to it.

Powered by Google App Engine
This is Rietveld 408576698